from pydantic import BaseModel, Field


class BotInformation(BaseModel):
    # The bot's ID
    id: str

    # The bot's name
    name: str

    # The bot's description
    description: str | None

    # List of constraints on the bot
    constraints: list["BotConstraint"]


class AllowedJidInformation(BaseModel):
    jid: str

    token: str


class BotConstraint(BaseModel): ...


class BotDomainConstraint(BotConstraint):
    domains: list[str]


class CreateBotRequest(BaseModel):
    # The bot's name
    name: str

    # The bot's description
    description: str | None = Field(default=None)

    # List of constraints
    constraints: list[BotConstraint] = Field(default_factory=list)


class BotCreationResponse(BotInformation):
    # The bot's token
    token: str


class AddJidRequest(BaseModel):
    jid: str


class AddJidResponse(BaseModel):
    token: str


class SendMessageRequest(BaseModel):
    # The message content
    body: str


class GetBotInformation(BotInformation):
    jids: list[AllowedJidInformation]
